# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ClassicManagerPermissions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_visible_in_transaction_rooms': 'bool',
        'can_delete_company_rooms': 'bool',
        'can_delete_company_documents': 'bool',
        'can_manage_company_rooms': 'bool',
        'can_manage_company_account': 'bool',
        'can_manage_company_shared_library': 'bool',
        'can_manage_company_members': 'bool',
        'can_close_company_rooms': 'bool',
        'can_approve_company_checklists': 'bool',
        'is_company_system_admin': 'bool',
        'is_region_manager': 'bool',
        'is_office_manager': 'bool',
        'auto_access_to_company_rooms': 'bool'
    }

    attribute_map = {
        'is_visible_in_transaction_rooms': 'isVisibleInTransactionRooms',
        'can_delete_company_rooms': 'canDeleteCompanyRooms',
        'can_delete_company_documents': 'canDeleteCompanyDocuments',
        'can_manage_company_rooms': 'canManageCompanyRooms',
        'can_manage_company_account': 'canManageCompanyAccount',
        'can_manage_company_shared_library': 'canManageCompanySharedLibrary',
        'can_manage_company_members': 'canManageCompanyMembers',
        'can_close_company_rooms': 'canCloseCompanyRooms',
        'can_approve_company_checklists': 'canApproveCompanyChecklists',
        'is_company_system_admin': 'isCompanySystemAdmin',
        'is_region_manager': 'isRegionManager',
        'is_office_manager': 'isOfficeManager',
        'auto_access_to_company_rooms': 'autoAccessToCompanyRooms'
    }

    def __init__(self, is_visible_in_transaction_rooms=None, can_delete_company_rooms=None, can_delete_company_documents=None, can_manage_company_rooms=None, can_manage_company_account=None, can_manage_company_shared_library=None, can_manage_company_members=None, can_close_company_rooms=None, can_approve_company_checklists=None, is_company_system_admin=None, is_region_manager=None, is_office_manager=None, auto_access_to_company_rooms=None):  # noqa: E501
        """ClassicManagerPermissions - a model defined in Swagger"""  # noqa: E501

        self._is_visible_in_transaction_rooms = None
        self._can_delete_company_rooms = None
        self._can_delete_company_documents = None
        self._can_manage_company_rooms = None
        self._can_manage_company_account = None
        self._can_manage_company_shared_library = None
        self._can_manage_company_members = None
        self._can_close_company_rooms = None
        self._can_approve_company_checklists = None
        self._is_company_system_admin = None
        self._is_region_manager = None
        self._is_office_manager = None
        self._auto_access_to_company_rooms = None
        self.discriminator = None

        if is_visible_in_transaction_rooms is not None:
            self.is_visible_in_transaction_rooms = is_visible_in_transaction_rooms
        if can_delete_company_rooms is not None:
            self.can_delete_company_rooms = can_delete_company_rooms
        if can_delete_company_documents is not None:
            self.can_delete_company_documents = can_delete_company_documents
        if can_manage_company_rooms is not None:
            self.can_manage_company_rooms = can_manage_company_rooms
        if can_manage_company_account is not None:
            self.can_manage_company_account = can_manage_company_account
        if can_manage_company_shared_library is not None:
            self.can_manage_company_shared_library = can_manage_company_shared_library
        if can_manage_company_members is not None:
            self.can_manage_company_members = can_manage_company_members
        if can_close_company_rooms is not None:
            self.can_close_company_rooms = can_close_company_rooms
        if can_approve_company_checklists is not None:
            self.can_approve_company_checklists = can_approve_company_checklists
        if is_company_system_admin is not None:
            self.is_company_system_admin = is_company_system_admin
        if is_region_manager is not None:
            self.is_region_manager = is_region_manager
        if is_office_manager is not None:
            self.is_office_manager = is_office_manager
        if auto_access_to_company_rooms is not None:
            self.auto_access_to_company_rooms = auto_access_to_company_rooms

    @property
    def is_visible_in_transaction_rooms(self):
        """Gets the is_visible_in_transaction_rooms of this ClassicManagerPermissions.  # noqa: E501


        :return: The is_visible_in_transaction_rooms of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible_in_transaction_rooms

    @is_visible_in_transaction_rooms.setter
    def is_visible_in_transaction_rooms(self, is_visible_in_transaction_rooms):
        """Sets the is_visible_in_transaction_rooms of this ClassicManagerPermissions.


        :param is_visible_in_transaction_rooms: The is_visible_in_transaction_rooms of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._is_visible_in_transaction_rooms = is_visible_in_transaction_rooms

    @property
    def can_delete_company_rooms(self):
        """Gets the can_delete_company_rooms of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_delete_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete_company_rooms

    @can_delete_company_rooms.setter
    def can_delete_company_rooms(self, can_delete_company_rooms):
        """Sets the can_delete_company_rooms of this ClassicManagerPermissions.


        :param can_delete_company_rooms: The can_delete_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_delete_company_rooms = can_delete_company_rooms

    @property
    def can_delete_company_documents(self):
        """Gets the can_delete_company_documents of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_delete_company_documents of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_delete_company_documents

    @can_delete_company_documents.setter
    def can_delete_company_documents(self, can_delete_company_documents):
        """Sets the can_delete_company_documents of this ClassicManagerPermissions.


        :param can_delete_company_documents: The can_delete_company_documents of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_delete_company_documents = can_delete_company_documents

    @property
    def can_manage_company_rooms(self):
        """Gets the can_manage_company_rooms of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_manage_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_company_rooms

    @can_manage_company_rooms.setter
    def can_manage_company_rooms(self, can_manage_company_rooms):
        """Sets the can_manage_company_rooms of this ClassicManagerPermissions.


        :param can_manage_company_rooms: The can_manage_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_company_rooms = can_manage_company_rooms

    @property
    def can_manage_company_account(self):
        """Gets the can_manage_company_account of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_manage_company_account of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_company_account

    @can_manage_company_account.setter
    def can_manage_company_account(self, can_manage_company_account):
        """Sets the can_manage_company_account of this ClassicManagerPermissions.


        :param can_manage_company_account: The can_manage_company_account of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_company_account = can_manage_company_account

    @property
    def can_manage_company_shared_library(self):
        """Gets the can_manage_company_shared_library of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_manage_company_shared_library of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_company_shared_library

    @can_manage_company_shared_library.setter
    def can_manage_company_shared_library(self, can_manage_company_shared_library):
        """Sets the can_manage_company_shared_library of this ClassicManagerPermissions.


        :param can_manage_company_shared_library: The can_manage_company_shared_library of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_company_shared_library = can_manage_company_shared_library

    @property
    def can_manage_company_members(self):
        """Gets the can_manage_company_members of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_manage_company_members of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_manage_company_members

    @can_manage_company_members.setter
    def can_manage_company_members(self, can_manage_company_members):
        """Sets the can_manage_company_members of this ClassicManagerPermissions.


        :param can_manage_company_members: The can_manage_company_members of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_manage_company_members = can_manage_company_members

    @property
    def can_close_company_rooms(self):
        """Gets the can_close_company_rooms of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_close_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_close_company_rooms

    @can_close_company_rooms.setter
    def can_close_company_rooms(self, can_close_company_rooms):
        """Sets the can_close_company_rooms of this ClassicManagerPermissions.


        :param can_close_company_rooms: The can_close_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_close_company_rooms = can_close_company_rooms

    @property
    def can_approve_company_checklists(self):
        """Gets the can_approve_company_checklists of this ClassicManagerPermissions.  # noqa: E501


        :return: The can_approve_company_checklists of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._can_approve_company_checklists

    @can_approve_company_checklists.setter
    def can_approve_company_checklists(self, can_approve_company_checklists):
        """Sets the can_approve_company_checklists of this ClassicManagerPermissions.


        :param can_approve_company_checklists: The can_approve_company_checklists of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._can_approve_company_checklists = can_approve_company_checklists

    @property
    def is_company_system_admin(self):
        """Gets the is_company_system_admin of this ClassicManagerPermissions.  # noqa: E501


        :return: The is_company_system_admin of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._is_company_system_admin

    @is_company_system_admin.setter
    def is_company_system_admin(self, is_company_system_admin):
        """Sets the is_company_system_admin of this ClassicManagerPermissions.


        :param is_company_system_admin: The is_company_system_admin of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._is_company_system_admin = is_company_system_admin

    @property
    def is_region_manager(self):
        """Gets the is_region_manager of this ClassicManagerPermissions.  # noqa: E501


        :return: The is_region_manager of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._is_region_manager

    @is_region_manager.setter
    def is_region_manager(self, is_region_manager):
        """Sets the is_region_manager of this ClassicManagerPermissions.


        :param is_region_manager: The is_region_manager of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._is_region_manager = is_region_manager

    @property
    def is_office_manager(self):
        """Gets the is_office_manager of this ClassicManagerPermissions.  # noqa: E501


        :return: The is_office_manager of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._is_office_manager

    @is_office_manager.setter
    def is_office_manager(self, is_office_manager):
        """Sets the is_office_manager of this ClassicManagerPermissions.


        :param is_office_manager: The is_office_manager of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._is_office_manager = is_office_manager

    @property
    def auto_access_to_company_rooms(self):
        """Gets the auto_access_to_company_rooms of this ClassicManagerPermissions.  # noqa: E501


        :return: The auto_access_to_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._auto_access_to_company_rooms

    @auto_access_to_company_rooms.setter
    def auto_access_to_company_rooms(self, auto_access_to_company_rooms):
        """Sets the auto_access_to_company_rooms of this ClassicManagerPermissions.


        :param auto_access_to_company_rooms: The auto_access_to_company_rooms of this ClassicManagerPermissions.  # noqa: E501
        :type: bool
        """

        self._auto_access_to_company_rooms = auto_access_to_company_rooms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClassicManagerPermissions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassicManagerPermissions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import auth modules into client package
from .auth.oauth import Account
from .auth.oauth import Organization
from .auth.oauth import Link
from .auth.oauth import OAuth
from .auth.oauth import OAuthToken
from .auth.oauth import OAuthUserInfo



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RoomSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'room_id': 'int',
        'name': 'str',
        'office_id': 'int',
        'created_date': 'datetime',
        'submitted_for_review_date': 'datetime',
        'closed_date': 'datetime',
        'rejected_date': 'datetime',
        'created_by_user_id': 'int',
        'rejected_by_user_id': 'int',
        'closed_status_id': 'str',
        'field_data_last_updated_date': 'datetime'
    }

    attribute_map = {
        'room_id': 'roomId',
        'name': 'name',
        'office_id': 'officeId',
        'created_date': 'createdDate',
        'submitted_for_review_date': 'submittedForReviewDate',
        'closed_date': 'closedDate',
        'rejected_date': 'rejectedDate',
        'created_by_user_id': 'createdByUserId',
        'rejected_by_user_id': 'rejectedByUserId',
        'closed_status_id': 'closedStatusId',
        'field_data_last_updated_date': 'fieldDataLastUpdatedDate'
    }

    def __init__(self, room_id=None, name=None, office_id=None, created_date=None, submitted_for_review_date=None, closed_date=None, rejected_date=None, created_by_user_id=None, rejected_by_user_id=None, closed_status_id=None, field_data_last_updated_date=None):  # noqa: E501
        """RoomSummary - a model defined in Swagger"""  # noqa: E501

        self._room_id = None
        self._name = None
        self._office_id = None
        self._created_date = None
        self._submitted_for_review_date = None
        self._closed_date = None
        self._rejected_date = None
        self._created_by_user_id = None
        self._rejected_by_user_id = None
        self._closed_status_id = None
        self._field_data_last_updated_date = None
        self.discriminator = None

        if room_id is not None:
            self.room_id = room_id
        if name is not None:
            self.name = name
        if office_id is not None:
            self.office_id = office_id
        if created_date is not None:
            self.created_date = created_date
        if submitted_for_review_date is not None:
            self.submitted_for_review_date = submitted_for_review_date
        if closed_date is not None:
            self.closed_date = closed_date
        if rejected_date is not None:
            self.rejected_date = rejected_date
        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        if rejected_by_user_id is not None:
            self.rejected_by_user_id = rejected_by_user_id
        if closed_status_id is not None:
            self.closed_status_id = closed_status_id
        if field_data_last_updated_date is not None:
            self.field_data_last_updated_date = field_data_last_updated_date

    @property
    def room_id(self):
        """Gets the room_id of this RoomSummary.  # noqa: E501


        :return: The room_id of this RoomSummary.  # noqa: E501
        :rtype: int
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """Sets the room_id of this RoomSummary.


        :param room_id: The room_id of this RoomSummary.  # noqa: E501
        :type: int
        """

        self._room_id = room_id

    @property
    def name(self):
        """Gets the name of this RoomSummary.  # noqa: E501


        :return: The name of this RoomSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RoomSummary.


        :param name: The name of this RoomSummary.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def office_id(self):
        """Gets the office_id of this RoomSummary.  # noqa: E501


        :return: The office_id of this RoomSummary.  # noqa: E501
        :rtype: int
        """
        return self._office_id

    @office_id.setter
    def office_id(self, office_id):
        """Sets the office_id of this RoomSummary.


        :param office_id: The office_id of this RoomSummary.  # noqa: E501
        :type: int
        """

        self._office_id = office_id

    @property
    def created_date(self):
        """Gets the created_date of this RoomSummary.  # noqa: E501


        :return: The created_date of this RoomSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this RoomSummary.


        :param created_date: The created_date of this RoomSummary.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def submitted_for_review_date(self):
        """Gets the submitted_for_review_date of this RoomSummary.  # noqa: E501


        :return: The submitted_for_review_date of this RoomSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._submitted_for_review_date

    @submitted_for_review_date.setter
    def submitted_for_review_date(self, submitted_for_review_date):
        """Sets the submitted_for_review_date of this RoomSummary.


        :param submitted_for_review_date: The submitted_for_review_date of this RoomSummary.  # noqa: E501
        :type: datetime
        """

        self._submitted_for_review_date = submitted_for_review_date

    @property
    def closed_date(self):
        """Gets the closed_date of this RoomSummary.  # noqa: E501


        :return: The closed_date of this RoomSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._closed_date

    @closed_date.setter
    def closed_date(self, closed_date):
        """Sets the closed_date of this RoomSummary.


        :param closed_date: The closed_date of this RoomSummary.  # noqa: E501
        :type: datetime
        """

        self._closed_date = closed_date

    @property
    def rejected_date(self):
        """Gets the rejected_date of this RoomSummary.  # noqa: E501


        :return: The rejected_date of this RoomSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._rejected_date

    @rejected_date.setter
    def rejected_date(self, rejected_date):
        """Sets the rejected_date of this RoomSummary.


        :param rejected_date: The rejected_date of this RoomSummary.  # noqa: E501
        :type: datetime
        """

        self._rejected_date = rejected_date

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this RoomSummary.  # noqa: E501


        :return: The created_by_user_id of this RoomSummary.  # noqa: E501
        :rtype: int
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this RoomSummary.


        :param created_by_user_id: The created_by_user_id of this RoomSummary.  # noqa: E501
        :type: int
        """

        self._created_by_user_id = created_by_user_id

    @property
    def rejected_by_user_id(self):
        """Gets the rejected_by_user_id of this RoomSummary.  # noqa: E501


        :return: The rejected_by_user_id of this RoomSummary.  # noqa: E501
        :rtype: int
        """
        return self._rejected_by_user_id

    @rejected_by_user_id.setter
    def rejected_by_user_id(self, rejected_by_user_id):
        """Sets the rejected_by_user_id of this RoomSummary.


        :param rejected_by_user_id: The rejected_by_user_id of this RoomSummary.  # noqa: E501
        :type: int
        """

        self._rejected_by_user_id = rejected_by_user_id

    @property
    def closed_status_id(self):
        """Gets the closed_status_id of this RoomSummary.  # noqa: E501


        :return: The closed_status_id of this RoomSummary.  # noqa: E501
        :rtype: str
        """
        return self._closed_status_id

    @closed_status_id.setter
    def closed_status_id(self, closed_status_id):
        """Sets the closed_status_id of this RoomSummary.


        :param closed_status_id: The closed_status_id of this RoomSummary.  # noqa: E501
        :type: str
        """

        self._closed_status_id = closed_status_id

    @property
    def field_data_last_updated_date(self):
        """Gets the field_data_last_updated_date of this RoomSummary.  # noqa: E501


        :return: The field_data_last_updated_date of this RoomSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._field_data_last_updated_date

    @field_data_last_updated_date.setter
    def field_data_last_updated_date(self, field_data_last_updated_date):
        """Sets the field_data_last_updated_date of this RoomSummary.


        :param field_data_last_updated_date: The field_data_last_updated_date of this RoomSummary.  # noqa: E501
        :type: datetime
        """

        self._field_data_last_updated_date = field_data_last_updated_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RoomSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages, os, Command  # noqa: H301

NAME = "docusign-rooms"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23",
    "setuptools >= 21.0.0",
    "PyJWT>=1.7.1",
    "cryptography>=2.5",
    "nose>=1.3.7"
]

class CleanCommand(Command):
    """Custom clean command to tidy up the project root."""
    user_options = []
    def initialize_options(self):
        pass
    def finalize_options(self):
        pass
    def run(self):
        os.system('rm -vrf ./build ./dist ./*.pyc ./*.tgz ./*.egg-info')

setup(
    name=NAME,
    version=VERSION,
    description="DocuSign Rooms API - v2",
    author_email="devcenter@docusign.com",
    url="",
    keywords=["Swagger", "DocuSign Rooms API - v2"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    cmdclass={
        'clean': CleanCommand,
    },
    long_description="""\
    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501
    """
)



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class OfficeSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'office_id': 'int',
        'name': 'str',
        'region_id': 'int',
        'address1': 'str',
        'address2': 'str',
        'city': 'str',
        'state_id': 'str',
        'postal_code': 'str',
        'country_id': 'str',
        'time_zone_id': 'str',
        'phone': 'str',
        'created_date': 'datetime'
    }

    attribute_map = {
        'office_id': 'officeId',
        'name': 'name',
        'region_id': 'regionId',
        'address1': 'address1',
        'address2': 'address2',
        'city': 'city',
        'state_id': 'stateId',
        'postal_code': 'postalCode',
        'country_id': 'countryId',
        'time_zone_id': 'timeZoneId',
        'phone': 'phone',
        'created_date': 'createdDate'
    }

    def __init__(self, office_id=None, name=None, region_id=None, address1=None, address2=None, city=None, state_id=None, postal_code=None, country_id=None, time_zone_id=None, phone=None, created_date=None):  # noqa: E501
        """OfficeSummary - a model defined in Swagger"""  # noqa: E501

        self._office_id = None
        self._name = None
        self._region_id = None
        self._address1 = None
        self._address2 = None
        self._city = None
        self._state_id = None
        self._postal_code = None
        self._country_id = None
        self._time_zone_id = None
        self._phone = None
        self._created_date = None
        self.discriminator = None

        if office_id is not None:
            self.office_id = office_id
        if name is not None:
            self.name = name
        if region_id is not None:
            self.region_id = region_id
        if address1 is not None:
            self.address1 = address1
        if address2 is not None:
            self.address2 = address2
        if city is not None:
            self.city = city
        if state_id is not None:
            self.state_id = state_id
        if postal_code is not None:
            self.postal_code = postal_code
        if country_id is not None:
            self.country_id = country_id
        if time_zone_id is not None:
            self.time_zone_id = time_zone_id
        if phone is not None:
            self.phone = phone
        if created_date is not None:
            self.created_date = created_date

    @property
    def office_id(self):
        """Gets the office_id of this OfficeSummary.  # noqa: E501


        :return: The office_id of this OfficeSummary.  # noqa: E501
        :rtype: int
        """
        return self._office_id

    @office_id.setter
    def office_id(self, office_id):
        """Sets the office_id of this OfficeSummary.


        :param office_id: The office_id of this OfficeSummary.  # noqa: E501
        :type: int
        """

        self._office_id = office_id

    @property
    def name(self):
        """Gets the name of this OfficeSummary.  # noqa: E501


        :return: The name of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OfficeSummary.


        :param name: The name of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def region_id(self):
        """Gets the region_id of this OfficeSummary.  # noqa: E501


        :return: The region_id of this OfficeSummary.  # noqa: E501
        :rtype: int
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this OfficeSummary.


        :param region_id: The region_id of this OfficeSummary.  # noqa: E501
        :type: int
        """

        self._region_id = region_id

    @property
    def address1(self):
        """Gets the address1 of this OfficeSummary.  # noqa: E501


        :return: The address1 of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """Sets the address1 of this OfficeSummary.


        :param address1: The address1 of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._address1 = address1

    @property
    def address2(self):
        """Gets the address2 of this OfficeSummary.  # noqa: E501


        :return: The address2 of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """Sets the address2 of this OfficeSummary.


        :param address2: The address2 of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._address2 = address2

    @property
    def city(self):
        """Gets the city of this OfficeSummary.  # noqa: E501


        :return: The city of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this OfficeSummary.


        :param city: The city of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state_id(self):
        """Gets the state_id of this OfficeSummary.  # noqa: E501


        :return: The state_id of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._state_id

    @state_id.setter
    def state_id(self, state_id):
        """Sets the state_id of this OfficeSummary.


        :param state_id: The state_id of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._state_id = state_id

    @property
    def postal_code(self):
        """Gets the postal_code of this OfficeSummary.  # noqa: E501


        :return: The postal_code of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this OfficeSummary.


        :param postal_code: The postal_code of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def country_id(self):
        """Gets the country_id of this OfficeSummary.  # noqa: E501


        :return: The country_id of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._country_id

    @country_id.setter
    def country_id(self, country_id):
        """Sets the country_id of this OfficeSummary.


        :param country_id: The country_id of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._country_id = country_id

    @property
    def time_zone_id(self):
        """Gets the time_zone_id of this OfficeSummary.  # noqa: E501


        :return: The time_zone_id of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._time_zone_id

    @time_zone_id.setter
    def time_zone_id(self, time_zone_id):
        """Sets the time_zone_id of this OfficeSummary.


        :param time_zone_id: The time_zone_id of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._time_zone_id = time_zone_id

    @property
    def phone(self):
        """Gets the phone of this OfficeSummary.  # noqa: E501


        :return: The phone of this OfficeSummary.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this OfficeSummary.


        :param phone: The phone of this OfficeSummary.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def created_date(self):
        """Gets the created_date of this OfficeSummary.  # noqa: E501


        :return: The created_date of this OfficeSummary.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this OfficeSummary.


        :param created_date: The created_date of this OfficeSummary.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OfficeSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfficeSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import, print_function
from docusign_rooms import RoomsApi, ApiException

import base64
import os
import unittest
import docusign_rooms as docusign

Username = os.environ.get("USER_NAME")
IntegratorKey = os.environ.get("INTEGRATOR_KEY_JWT")
BaseUrl = "https://demo.rooms.docusign.com/restapi"
OauthHostName = "account-d.docusign.com"
SignTest1File = "{}/docs/SignTest1.pdf".format(os.path.dirname(os.path.abspath(__file__)))
TemplateId = os.environ.get("TEMPLATE_ID")
UserId = os.environ.get("USER_ID")
PrivateKeyBytes = base64.b64decode(os.environ.get("PRIVATE_KEY"))


class SdkUnitTests(unittest.TestCase):

    def setUp(self):
        self.api_client = docusign.ApiClient(base_path=BaseUrl, oauth_host_name=OauthHostName)
        self.api_client.rest_client.pool_manager.clear()

        docusign.configuration.api_client = self.api_client
        try:
            self.api_client.host = BaseUrl
            token = (self.api_client.request_jwt_user_token(client_id=IntegratorKey,
                                                            user_id=UserId,
                                                            oauth_host_name=OauthHostName,
                                                            private_key_bytes=PrivateKeyBytes,
                                                            expires_in=3600,
                                                            scopes=["signature", "impersonation",
                                                                    "dtr.rooms.read", "dtr.rooms.write",
                                                                    "dtr.company.read","dtr.company.write"]))
            self.user_info = self.api_client.get_user_info(token.access_token)
            self.api_client.rest_client.pool_manager.clear()
            docusign.configuration.api_client = self.api_client

        except ApiException as e:
            print("\nException when setting up DocuSign Rooms API: %s" % e)
        self.api_client.rest_client.pool_manager.clear()

    def tearDown(self):
        self.api_client.rest_client.pool_manager.clear()

    def testGetRooms(self):
        # Testing for the UserInfo which is true if auth is successful
        print(self.user_info)
        self.assertIsNotNone(self.user_info)
        self.assertTrue(len(self.user_info.accounts) > 0)
        self.assertIsNotNone(self.user_info.accounts[0].account_id)

        # Get the active room
        accountId = self.user_info.accounts[0].account_id
        rooms = RoomsApi()
        activeRoom = rooms.get_rooms(accountId)

        self.assertIsNotNone(activeRoom)
        self.assertTrue(len(activeRoom.rooms) > 0)
        self.assertIsNotNone(activeRoom.rooms[0].room_id)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DocuSign Rooms API - v2

    An API for an integrator to access the features of DocuSign Rooms  # noqa: E501

    OpenAPI spec version: v2
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..client.configuration import Configuration
from ..client.api_client import ApiClient


class UsersApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def add_user_to_office(self, user_id, designated_office, account_id, **kwargs):
        """
        Adds the user to the designated office.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_user_to_office(user_id, designated_office, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedOffice designated_office:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_user_to_office_with_http_info(user_id, designated_office, account_id, **kwargs)
        else:
            (data) = self.add_user_to_office_with_http_info(user_id, designated_office, account_id, **kwargs)
            return data

    def add_user_to_office_with_http_info(self, user_id, designated_office, account_id, **kwargs):
        """
        Adds the user to the designated office.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_user_to_office_with_http_info(user_id, designated_office, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedOffice designated_office:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'designated_office', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_user_to_office" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `add_user_to_office`")
        # verify the required parameter 'designated_office' is set
        if ('designated_office' not in params) or (params['designated_office'] is None):
            raise ValueError("Missing the required parameter `designated_office` when calling `add_user_to_office`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `add_user_to_office`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/add_to_office'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'designated_office' in params:
            body_params = params['designated_office']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def add_user_to_region(self, user_id, designated_region, account_id, **kwargs):
        """
        Adds the user to the designated region.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_user_to_region(user_id, designated_region, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedRegion designated_region:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.add_user_to_region_with_http_info(user_id, designated_region, account_id, **kwargs)
        else:
            (data) = self.add_user_to_region_with_http_info(user_id, designated_region, account_id, **kwargs)
            return data

    def add_user_to_region_with_http_info(self, user_id, designated_region, account_id, **kwargs):
        """
        Adds the user to the designated region.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.add_user_to_region_with_http_info(user_id, designated_region, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedRegion designated_region:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'designated_region', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_user_to_region" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `add_user_to_region`")
        # verify the required parameter 'designated_region' is set
        if ('designated_region' not in params) or (params['designated_region'] is None):
            raise ValueError("Missing the required parameter `designated_region` when calling `add_user_to_region`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `add_user_to_region`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/add_to_region'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'designated_region' in params:
            body_params = params['designated_region']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_user(self, user_id, account_id, **kwargs):
        """
        Retrieves user information for the user having the given UserId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_user_with_http_info(user_id, account_id, **kwargs)
        else:
            (data) = self.get_user_with_http_info(user_id, account_id, **kwargs)
            return data

    def get_user_with_http_info(self, user_id, account_id, **kwargs):
        """
        Retrieves user information for the user having the given UserId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_user_with_http_info(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_users(self, account_id, **kwargs):
        """
        Gets a paged-list of users.
        Retrieves a paged-list of Company Users in the User's company using the given filter and sort parameters.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_users(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param str filter: Filters by name and email
        :param str sort: Valid values are 'FirstNameAsc', 'FirstNameDesc', 'LastNameAsc', 'LastNameDesc', 'EmailAsc', 'EmailDesc'
        :param int default_office_id: 
        :param str access_level: Valid values are 'Company', 'Region', 'Office', 'Contributor'
        :param int title_id: Only valid for classic companies
        :param int role_id: Only valid for next gen companies
        :param str status: Valid values are 'Active', 'Pending'
        :param bool locked_only: 
        :param int start_position: Defaults to 0
        :param int count: Defaults to 100. Must be less than or equal to 100
        :return: UserSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_users_with_http_info(account_id, **kwargs)
        else:
            (data) = self.get_users_with_http_info(account_id, **kwargs)
            return data

    def get_users_with_http_info(self, account_id, **kwargs):
        """
        Gets a paged-list of users.
        Retrieves a paged-list of Company Users in the User's company using the given filter and sort parameters.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_users_with_http_info(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: (required)
        :param str filter: Filters by name and email
        :param str sort: Valid values are 'FirstNameAsc', 'FirstNameDesc', 'LastNameAsc', 'LastNameDesc', 'EmailAsc', 'EmailDesc'
        :param int default_office_id: 
        :param str access_level: Valid values are 'Company', 'Region', 'Office', 'Contributor'
        :param int title_id: Only valid for classic companies
        :param int role_id: Only valid for next gen companies
        :param str status: Valid values are 'Active', 'Pending'
        :param bool locked_only: 
        :param int start_position: Defaults to 0
        :param int count: Defaults to 100. Must be less than or equal to 100
        :return: UserSummaryList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'filter', 'sort', 'default_office_id', 'access_level', 'title_id', 'role_id', 'status', 'locked_only', 'start_position', 'count']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_users" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_users`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'filter' in params:
            query_params['filter'] = params['filter']
        if 'sort' in params:
            query_params['sort'] = params['sort']
        if 'default_office_id' in params:
            query_params['defaultOfficeId'] = params['default_office_id']
        if 'access_level' in params:
            query_params['accessLevel'] = params['access_level']
        if 'title_id' in params:
            query_params['titleId'] = params['title_id']
        if 'role_id' in params:
            query_params['roleId'] = params['role_id']
        if 'status' in params:
            query_params['status'] = params['status']
        if 'locked_only' in params:
            query_params['lockedOnly'] = params['locked_only']
        if 'start_position' in params:
            query_params['startPosition'] = params['start_position']
        if 'count' in params:
            query_params['count'] = params['count']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='UserSummaryList',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def invite_classic_admin(self, invitee, account_id, **kwargs):
        """
        CLASSIC COMPANY ONLY. Send an invitation to join the company as an admin.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_classic_admin(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ClassicAdminToInvite invitee: Invitee information. (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.invite_classic_admin_with_http_info(invitee, account_id, **kwargs)
        else:
            (data) = self.invite_classic_admin_with_http_info(invitee, account_id, **kwargs)
            return data

    def invite_classic_admin_with_http_info(self, invitee, account_id, **kwargs):
        """
        CLASSIC COMPANY ONLY. Send an invitation to join the company as an admin.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_classic_admin_with_http_info(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ClassicAdminToInvite invitee: Invitee information. (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invitee', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_classic_admin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invitee' is set
        if ('invitee' not in params) or (params['invitee'] is None):
            raise ValueError("Missing the required parameter `invitee` when calling `invite_classic_admin`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `invite_classic_admin`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/invite_classic_admin'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'invitee' in params:
            body_params = params['invitee']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def invite_classic_agent(self, invitee, account_id, **kwargs):
        """
        CLASSIC COMPANY ONLY. Send an invitation to join the company as an agent.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_classic_agent(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ClassicAgentToInvite invitee: Invitee information. (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.invite_classic_agent_with_http_info(invitee, account_id, **kwargs)
        else:
            (data) = self.invite_classic_agent_with_http_info(invitee, account_id, **kwargs)
            return data

    def invite_classic_agent_with_http_info(self, invitee, account_id, **kwargs):
        """
        CLASSIC COMPANY ONLY. Send an invitation to join the company as an agent.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_classic_agent_with_http_info(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ClassicAgentToInvite invitee: Invitee information. (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invitee', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_classic_agent" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invitee' is set
        if ('invitee' not in params) or (params['invitee'] is None):
            raise ValueError("Missing the required parameter `invitee` when calling `invite_classic_agent`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `invite_classic_agent`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/invite_classic_agent'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'invitee' in params:
            body_params = params['invitee']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def invite_classic_manager(self, invitee, account_id, **kwargs):
        """
        CLASSIC COMPANY ONLY. Send an invitation to join the company as a manager.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_classic_manager(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ClassicManagerToInvite invitee: Invitee information. (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.invite_classic_manager_with_http_info(invitee, account_id, **kwargs)
        else:
            (data) = self.invite_classic_manager_with_http_info(invitee, account_id, **kwargs)
            return data

    def invite_classic_manager_with_http_info(self, invitee, account_id, **kwargs):
        """
        CLASSIC COMPANY ONLY. Send an invitation to join the company as a manager.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_classic_manager_with_http_info(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ClassicManagerToInvite invitee: Invitee information. (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invitee', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_classic_manager" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invitee' is set
        if ('invitee' not in params) or (params['invitee'] is None):
            raise ValueError("Missing the required parameter `invitee` when calling `invite_classic_manager`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `invite_classic_manager`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/invite_classic_manager'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'invitee' in params:
            body_params = params['invitee']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def invite_user(self, invitee, account_id, **kwargs):
        """
        NON-CLASSIC COMPANY ONLY. Send an invitation to the user or non-user having the given email.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_user(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserToInvite invitee: Invitee information (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.invite_user_with_http_info(invitee, account_id, **kwargs)
        else:
            (data) = self.invite_user_with_http_info(invitee, account_id, **kwargs)
            return data

    def invite_user_with_http_info(self, invitee, account_id, **kwargs):
        """
        NON-CLASSIC COMPANY ONLY. Send an invitation to the user or non-user having the given email.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.invite_user_with_http_info(invitee, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param UserToInvite invitee: Invitee information (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invitee', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invite_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invitee' is set
        if ('invitee' not in params) or (params['invitee'] is None):
            raise ValueError("Missing the required parameter `invitee` when calling `invite_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `invite_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/invite_user'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'invitee' in params:
            body_params = params['invitee']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def lock_user(self, user_id, details, account_id, **kwargs):
        """
        Locks the account of the user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.lock_user(user_id, details, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id: User Id of the user attempting to be locked. (required)
        :param LockedOutDetails details: Details containing the reason the user is being locked out (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.lock_user_with_http_info(user_id, details, account_id, **kwargs)
        else:
            (data) = self.lock_user_with_http_info(user_id, details, account_id, **kwargs)
            return data

    def lock_user_with_http_info(self, user_id, details, account_id, **kwargs):
        """
        Locks the account of the user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.lock_user_with_http_info(user_id, details, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id: User Id of the user attempting to be locked. (required)
        :param LockedOutDetails details: Details containing the reason the user is being locked out (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'details', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lock_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `lock_user`")
        # verify the required parameter 'details' is set
        if ('details' not in params) or (params['details'] is None):
            raise ValueError("Missing the required parameter `details` when calling `lock_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `lock_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/lock'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'details' in params:
            body_params = params['details']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def reinvite_user(self, user_id, account_id, **kwargs):
        """
        Reinvites the pending user with the given userId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reinvite_user(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.reinvite_user_with_http_info(user_id, account_id, **kwargs)
        else:
            (data) = self.reinvite_user_with_http_info(user_id, account_id, **kwargs)
            return data

    def reinvite_user_with_http_info(self, user_id, account_id, **kwargs):
        """
        Reinvites the pending user with the given userId.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.reinvite_user_with_http_info(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reinvite_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `reinvite_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `reinvite_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/reinvite'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def remove_user(self, user_id, account_id, **kwargs):
        """
        Removes a user from the company.
        Removes the user. Will fail if the user owns any Rooms.   The rooms will need to be transferred to other agents before removing.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id: Id of the user you wish to remove. (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_user_with_http_info(user_id, account_id, **kwargs)
        else:
            (data) = self.remove_user_with_http_info(user_id, account_id, **kwargs)
            return data

    def remove_user_with_http_info(self, user_id, account_id, **kwargs):
        """
        Removes a user from the company.
        Removes the user. Will fail if the user owns any Rooms.   The rooms will need to be transferred to other agents before removing.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_with_http_info(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id: Id of the user you wish to remove. (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `remove_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `remove_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def remove_user_from_office(self, user_id, designated_office, account_id, **kwargs):
        """
        Removes the user from the designated office.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_from_office(user_id, designated_office, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedOffice designated_office:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_user_from_office_with_http_info(user_id, designated_office, account_id, **kwargs)
        else:
            (data) = self.remove_user_from_office_with_http_info(user_id, designated_office, account_id, **kwargs)
            return data

    def remove_user_from_office_with_http_info(self, user_id, designated_office, account_id, **kwargs):
        """
        Removes the user from the designated office.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_from_office_with_http_info(user_id, designated_office, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedOffice designated_office:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'designated_office', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_user_from_office" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `remove_user_from_office`")
        # verify the required parameter 'designated_office' is set
        if ('designated_office' not in params) or (params['designated_office'] is None):
            raise ValueError("Missing the required parameter `designated_office` when calling `remove_user_from_office`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `remove_user_from_office`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/remove_from_office'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'designated_office' in params:
            body_params = params['designated_office']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def remove_user_from_region(self, user_id, designated_region, account_id, **kwargs):
        """
        Removes the user from the designated region.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_from_region(user_id, designated_region, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedRegion designated_region:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.remove_user_from_region_with_http_info(user_id, designated_region, account_id, **kwargs)
        else:
            (data) = self.remove_user_from_region_with_http_info(user_id, designated_region, account_id, **kwargs)
            return data

    def remove_user_from_region_with_http_info(self, user_id, designated_region, account_id, **kwargs):
        """
        Removes the user from the designated region.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.remove_user_from_region_with_http_info(user_id, designated_region, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param DesignatedRegion designated_region:  (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'designated_region', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_user_from_region" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `remove_user_from_region`")
        # verify the required parameter 'designated_region' is set
        if ('designated_region' not in params) or (params['designated_region'] is None):
            raise ValueError("Missing the required parameter `designated_region` when calling `remove_user_from_region`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `remove_user_from_region`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/remove_from_region'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'designated_region' in params:
            body_params = params['designated_region']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def unlock_user(self, user_id, account_id, **kwargs):
        """
        Unlocks the account of the user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.unlock_user(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id: User Id of the user attempting to be unlocked. (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.unlock_user_with_http_info(user_id, account_id, **kwargs)
        else:
            (data) = self.unlock_user_with_http_info(user_id, account_id, **kwargs)
            return data

    def unlock_user_with_http_info(self, user_id, account_id, **kwargs):
        """
        Unlocks the account of the user.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.unlock_user_with_http_info(user_id, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id: User Id of the user attempting to be unlocked. (required)
        :param str account_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unlock_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `unlock_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `unlock_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}/unlock'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_user(self, user_id, user_for_update, account_id, **kwargs):
        """
        Updates user information
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_user(user_id, user_for_update, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param UserForUpdate user_for_update:  (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_user_with_http_info(user_id, user_for_update, account_id, **kwargs)
        else:
            (data) = self.update_user_with_http_info(user_id, user_for_update, account_id, **kwargs)
            return data

    def update_user_with_http_info(self, user_id, user_for_update, account_id, **kwargs):
        """
        Updates user information
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_user_with_http_info(user_id, user_for_update, account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int user_id:  (required)
        :param UserForUpdate user_for_update:  (required)
        :param str account_id: (required)
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'user_for_update', 'account_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params) or (params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `update_user`")
        # verify the required parameter 'user_for_update' is set
        if ('user_for_update' not in params) or (params['user_for_update'] is None):
            raise ValueError("Missing the required parameter `user_for_update` when calling `update_user`")
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `update_user`")


        collection_formats = {}

        resource_path = '/v2/accounts/{accountId}/users/{userId}'.replace('{format}', 'json')
        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_for_update' in params:
            body_params = params['user_for_update']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='User',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)
